@@ -45,9 +45,11 @@ SCHEMA = "schema"
 CONFIG_FILE_EXT = ".json"
 CONFIG_FILE_SCHEMA = f"{CONFIG_FOLDER}/config_{SCHEMA}.json"
 CONFIG_REFRESH_RATE = "refresh_rate_seconds"
+CONFIG_SAVED_HISTORICAL_TIMEFRAMES = "saved_historical_timeframes"
 CONFIG_OPTIMIZER_ID = "optimizer_id"
 CONFIG_BACKTESTING_ID = "backtesting_id"
-CONFIG_SAVED_HISTORICAL_TIMEFRAMES = "saved_historical_timeframes"
+CONFIG_CURRENT_LIVE_ID = "current-live-id"
+DEFAULT_CURRENT_LIVE_ID = 1
 
 # profiles
 PROFILES_FOLDER = "profiles"
@@ -65,6 +67,7 @@ CONFIG_ID = "id"
 PROFILE_FILE_SCHEMA = f"{CONFIG_FOLDER}/profile_{SCHEMA}.json"
 PROFILE_EXPORT_FORMAT = "zip"
 IMPORTED_PROFILE_PREFIX = "imported"
+USE_CURRENT_PROFILE = "use_current_profile"
 
 # Config currencies
 CONFIG_CRYPTO_CURRENCIES = "crypto-currencies"
@@ -79,6 +82,7 @@ CONFIG_EXCHANGE_KEY = "api-key"
 CONFIG_EXCHANGE_SECRET = "api-secret"
 CONFIG_EXCHANGE_PASSWORD = "api-password"
 CONFIG_EXCHANGE_TYPE = "exchange-type"
+CONFIG_CONTRACT_TYPE = "contract-type"
 CONFIG_EXCHANGE_SANDBOXED = "sandboxed"
 CONFIG_EXCHANGE_FUTURE = "future"
 CONFIG_EXCHANGE_MARGIN = "margin"
